# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add requires qa and sealed flags

Revision ID: 2dd9ea1b821e
Revises: baf4d187d454
Create Date: 2022-01-13 16:32:20.769363

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "2dd9ea1b821e"
down_revision = "baf4d187d454"
branch_labels = None
depends_on = None

qa_capabilities = ["std_calibration", "std_cms_imaging"]


def upgrade():
    op.execute(
        """
        ALTER TABLE capabilities
        ADD COLUMN requires_qa bool NOT NULL DEFAULT false
        """
    )
    for capability in qa_capabilities:
        op.execute(
            f"""
            UPDATE capabilities
            SET requires_qa = TRUE WHERE capability_name = '{capability}'
            """
        )
    op.execute(
        """
        ALTER TABLE capabilities
        ADD COLUMN single_version_only bool NOT NULL DEFAULT false
        """
    )
    op.execute(
        """
        UPDATE capabilities
        SET single_version_only = True WHERE capability_name='test_download'
        """
    )
    op.execute(
        """
        ALTER TABLE capability_requests
        ADD COLUMN sealed bool NOT NULL DEFAULT false
        """
    )
    op.execute(
        """
        ALTER TABLE capability_versions
        ADD COLUMN sealed bool NOT NULL DEFAULT false
        """
    )


def downgrade():
    op.execute(
        """
        ALTER TABLE capabilities DROP COLUMN  IF EXISTS requires_qa
        """
    )
    op.execute(
        """
        ALTER TABLE capabilities DROP COLUMN  IF EXISTS single_version_only
        """
    )
    op.execute(
        """
        ALTER TABLE capability_requests DROP COLUMN  IF EXISTS sealed
        """
    )
    op.execute(
        """
        ALTER TABLE capability_versions DROP COLUMN  IF EXISTS sealed
        """
    )
