# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""
Tests for the Workflow Monitor Reacquisition system
"""
from pathlib import Path
from unittest.mock import MagicMock, mock_open, patch

from pendulum import DateTime

import workspaces.workflow.services.recovery as recovery

from test.conftest import mock_workflow_requests

fake_profile = "test-dev"


@patch("pathlib.Path.exists", MagicMock(return_value=True))
def test_ensure_initial_setup_false():
    assert recovery._ensure_initial_startup() is False


@patch("pathlib.Path.exists", MagicMock(return_value=False))
@patch("pendulum.now", MagicMock(return_value=DateTime(2022, 3, 30, 22, 22, 17)))
def test_ensure_initial_setup_true():
    with patch("builtins.open", mock_open()) as o:
        recovery._ensure_initial_startup()
        o.assert_called_with("reacquire.txt", "w")
        handle = o()
        content = "The Workflow Reacquire system was started within this container at 2022-03-30T22:22:17\n"
        handle.write.assert_called_with(content)
        handle.close.assert_called_once()


@patch.dict("os.environ", {"CAPO_PROFILE": fake_profile})
def test_get_environment():
    assert recovery.get_environment() == "dev"


class TestMonitorRecover:
    # def test_on_restart(self):
    #     pass

    def test_reacquire_logfile_empty_path(self, mock_workflow_requests):
        assert recovery.MonitorRecover._reacquire_logfile(mock_workflow_requests[0]) == Path(".")

    # def test_reacquire_logfile_path(self):
    #     pass

    # @patch("subprocess.Popen")
    # def test_restart_monitor(self, mock_subprocess):
    #     pass
    #
    # def test_reacquire_inflight_requests(self):
    #     pass
